Learn R Programming

NSA (version 0.0.2)

snpsNByTotalAndFracB.matrix: Normalize allele-specific copy numbers (total,fracB)

Description

Normalize allele-specific copy numbers (total,fracB), where total is the total (non-polymorphic) signal and fracB is the allele B fraction. It is only loci with a non-missing (NA) fracB value that are considered to be SNPs and normalized by CalMaTe. The other loci are left untouched.

Usage

## S3 method for class 'matrix':
snpsNByTotalAndFracB(data, references=NULL, ..., verbose=FALSE)

Arguments

data
An Jx2xI numeric array, where J is the number of loci, 2 is total and fracB, and I is the number of samples.
references
A logical or numeric vector specifying which samples should be used as the reference set.
...
Additional arguments passed to fitSNPsN.
verbose
See Verbose.

Value